.. image:: ../artwork/logo.png
  :width: 300px
  :align: right

Welcome!
========

Buildcat is the lightweight, flexible render farm implemented using
`Python <https://python.org>`_, `RQ <http://python-rq.org>`_ and `Redis <https://redis.io>`_.
It runs on MacOS, Linux, and Windows (WSL), requires almost no configuration, includes
integrations for `Houdini <https://sidefx.com>`_, `Modo
<https://www.foundry.com/products/modo>`_, and `Redshift
<https://www.redshift3d.com>`_, and can be easily extended to support other
tools.

Documentation
=============

.. toctree::
   :maxdepth: 2

   installation.rst
   tutorial.rst
   user-guide.rst
   commands.rst
   development.rst
   reference.rst
   compatibility.rst
   release-notes.rst
   support.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

